@@ -117,6 +117,16 @@ namespace gx_effects {
 #include "faust/peak_eq.cc"
 #include "faust/digital_delay.cc"
 #include "faust/digital_delay_st.cc"
+#include "faust/dattorros_progenitor.cc"
+#include "faust/ring_modulator.cc"
+#include "faust/ring_modulator_st.cc"
+#include "faust/panoram_enhancer.cc"
+#include "faust/graphiceq.cc"
+#include "faust/bass_enhancer.cc"
+#include "faust/gain.cc"
+#include "faust/duck_delay.cc"
+#include "faust/duck_delay_st.cc"
+
 }
 
 #include "faust/balance.cc"
