@@ -105,6 +105,7 @@ inline void JsonWriter::iminus() {
 
 template<class T> static inline T fp_sanitize(T v) {
     switch (fpclassify(v)) {
+    case FP_NORMAL: return v;
     case FP_NAN: assert(false); return 1e50;
     case FP_INFINITE: assert(false); return (v < 0 ? -1e50 : 1e50);
     case FP_SUBNORMAL: return 0;
@@ -417,12 +418,12 @@ JsonParser::token JsonParser::read_value_token(char c) {
 	return value_false;
     }
     // sanitize bad input
-    if (next_str == "nan" && next_str == "inf") {
+    if (next_str == "nan" || next_str == "inf") {
 	assert(false);
 	next_str = "1e50";
 	return value_number;
     }
-    if (next_str == "-inf") {
+    if (next_str == "-nan" || next_str == "-inf") {
 	assert(false);
 	next_str = "-1e50";
 	return value_number;
