@@ -317,6 +317,52 @@ void StackBoxBuilder::create_simple_meter(const std::string& id) {
     fBox.box_pack_start(manage(box),false);
 }
 
+void StackBoxBuilder::create_simple_c_meter(const std::string& id, const std::string& idm, const char *label) {
+    Gxw::FastMeter *fastmeter = new Gxw::FastMeter();
+    fastmeter->set_hold_count(5);
+    fastmeter->set_property("dimen",5);
+    Glib::signal_timeout().connect(sigc::bind<Gxw::FastMeter*>(sigc::bind<const std::string>(
+      sigc::mem_fun(*this, &StackBoxBuilder::set_simple),id), fastmeter), 60);
+    fastmeter->set_by_power(0.0001);
+    Gxw::LevelSlider *w = new UiRegler<Gxw::LevelSlider>(machine, idm);
+    w->set_name("lmw");
+    GxPaintBox *box =  new GxPaintBox("simple_level_meter_expose");
+    box->set_border_width(2);
+    box->pack_start(*Gtk::manage(static_cast<Gtk::Widget*>(fastmeter)),Gtk::PACK_SHRINK);
+    box->add(*Gtk::manage(static_cast<Gtk::Widget*>(w)));
+    if (label && label[0]) {
+    GxPaintBox *boxv =  new GxPaintBox(pb_eq_expose);
+    boxv->set_property("orientation",Gtk::ORIENTATION_VERTICAL);
+    boxv->set_homogeneous(false);
+    boxv->set_spacing(0);
+    boxv->set_border_width(4);
+    Gtk::Label *lab = new Gtk::Label(label);
+    Pango::FontDescription font = lab->get_style()->get_font();
+    font.set_size(6*Pango::SCALE);
+    font.set_weight(Pango::WEIGHT_NORMAL);
+    lab->modify_font(font);
+    lab->set_name("beffekt_label");
+    boxv->add(*manage(lab));
+    Gtk::VBox *boxvv =  new Gtk::VBox();
+    Gtk::HBox *boxl =  new Gtk::HBox();
+    boxl->set_homogeneous(false);
+    boxl->set_spacing(0);
+    boxl->set_border_width(0);
+    Gtk::HBox *boxr =  new Gtk::HBox();
+    Gtk::HBox *boxs =  new Gtk::HBox();
+    boxl->pack_start(*manage(boxr), Gtk::PACK_EXPAND_WIDGET);
+    boxl->add(*manage(box));
+    boxl->pack_end(*manage(boxs), Gtk::PACK_EXPAND_WIDGET);
+    boxvv->add(*manage(boxv));    
+    boxvv->add(*manage(boxl));    
+    boxvv->show_all();
+    fBox.box_pack_start(manage(boxvv),false);
+    } else {
+    box->show_all();
+    fBox.box_pack_start(manage(box),false);
+    }
+}
+
 bool StackBoxBuilder::set_engine_value(const std::string id) {
     if (machine.get_parameter_value<bool>(id.substr(0,id.find_last_of(".")+1)+"on_off"))
       machine.signal_parameter_value<float>(id)(machine.get_parameter_value<float>(id));
@@ -331,12 +377,47 @@ void StackBoxBuilder::create_port_display(const std::string& id, const char *lab
 	addwidget(w);
 }
 
+bool StackBoxBuilder::set_pd_value(Gxw::PortDisplay *w, const std::string id, const std::string& idl, const std::string& idh) {
+    if (machine.get_parameter_value<bool>(id.substr(0,id.find_last_of(".")+1)+"on_off")) {
+      float low = machine.get_parameter_value<float>(idl);
+      float high = 100-machine.get_parameter_value<float>(idh);
+      w->set_state(int(low),int(high));
+      float set = (low + high)*0.001;
+      machine.signal_parameter_value<float>(id)(machine.get_parameter_value<float>(id)+set);
+    }
+    return true;
+}
+    
+void StackBoxBuilder::create_p_display(const std::string& id, const std::string& idl, const std::string& idh) {
+    Gxw::PortDisplay *w = new UiRegler<Gxw::PortDisplay>(machine, id);
+    Glib::signal_timeout().connect(sigc::bind<Gxw::PortDisplay*>(sigc::bind<const std::string>(
+      sigc::bind<const std::string>(sigc::bind<const std::string>(
+      sigc::mem_fun(*this, &StackBoxBuilder::set_pd_value),idh),idl),id),w ), 60);
+	w->set_name("playhead");
+    Gtk::EventBox* e_box = new Gtk::EventBox();
+    e_box->set_size_request(-1, -1);
+    e_box->set_border_width(0);
+    e_box->set_visible_window(true);
+    e_box->set_above_child(true);
+    e_box->add(*manage(static_cast<Gtk::Widget*>(w)));
+    addwidget(e_box);
+    e_box->show_all();
+}
+
 void StackBoxBuilder::create_feedback_switch(const char *sw_type, const std::string& id) {
 	addwidget(UiSwitch::create(machine, sw_type, id));
     Glib::signal_timeout().connect(sigc::bind<const std::string>(
       sigc::mem_fun(*this, &StackBoxBuilder::set_engine_value),id), 60);
 }
 
+void StackBoxBuilder::create_feedback_slider(const std::string& id, const char *label) {
+	UiMasterReglerWithCaption<Gxw::HSlider> *w = new UiMasterReglerWithCaption<Gxw::HSlider>(machine, id);
+    Glib::signal_timeout().connect(sigc::bind<const std::string>(
+      sigc::mem_fun(*this, &StackBoxBuilder::set_engine_value),id), 60);
+	w->set_label(label);
+	addwidget(w);
+    }
+
 void StackBoxBuilder::create_selector(const std::string& id, const char *widget_name) {
     gx_engine::Parameter& p = machine.get_parameter(id);
     Gxw::Selector *s;
