@@ -95,7 +95,14 @@ GxMachine::GxMachine(gx_system::CmdlineOptions& options_):
     gx_engine::get_group_table().insert("racktuner", N_("Rack Tuner"));
     static const value_pair streaming_labels[] = {{"scale"}, {"stream"}, {0}};
     pmap.reg_non_midi_enum_par("racktuner.streaming", "Streaming Mode", streaming_labels, (int*)0, false, 1);
-    static const value_pair tuning_labels[] = {{"(Chromatic)"},{"Standard"}, {"Standard/Es"}, {"Open E"}, {0}};
+    static const value_pair tuning_labels[] = {{"(Chromatic)"},{"Standard"}, {"Standard/Es"}, {"Open E"}, 
+        {"Drop D"},{"Half Step Down"},{"Full Step Down"},{"1 and 1/2 Steps Down"},{"Double Drop D"},{"Drop C"},
+        {"Drop C#"},{"Drop B"},{"Drop A#"},{"Drop A"},{"Open D"},{"Open D Minor"}, {"Open G"},{"Open G Minor"},
+        {"Open C"},{"Open C#"},{"Open C Minor"},{"Open E7"},{"Open E Minor7"},{"Open G Major7"},{"Open A Minor"},
+        {"Open A Minor7"},{"Open A"},{"C Tuning"},{"C# Tuning"},{"Bb Tuning"},{"A to A (Baritone)"},{"Open Dsus2"},
+        {"Open Gsus2"},{"G6"},{"Modal G"},{"Overtone"},{"Pentatonic"},{"Minor Third"},{"Major Third"},{"All Fourths"},
+        {"Augmented Fourths"},{"Slow Motion"},{"Admiral"},{"Buzzard"},{"Face"},{"Four and Twenty"},{"Ostrich"},{"Capo 200"},
+        {"Balalaika"},{"Cittern One"},{"Cittern Two"},{"Dobro"},{"Lefty"},{"Mandoguitar"},{"Rusty Cage"},{"Hardcore"}, {0}};
     pmap.reg_non_midi_enum_par("racktuner.tuning", "Tuning", tuning_labels, (int*)0, false, 0);
     pmap.reg_par_non_preset("racktuner.scale_lim", "Limit", 0, 3.0, 1.0, 10.0, 1.0);
     pmap.reg_par_non_preset("ui.tuner_reference_pitch", "?Tuner Reference Pitch", 0, 440, 427, 453, 0.1);
@@ -1467,9 +1474,9 @@ int GxMachineRemote::load_remote_ui(const UiBuilder& builder, int form) {
 	} else if (jp->current_value() == "create_master_slider") {
 	    std::string id = next_string(jp);
 	    builder.create_master_slider(id.c_str(), next_char_pointer(jp));
-	} else if (jp->current_value() == "create_h_slider") {
+	} else if (jp->current_value() == "create_feedback_slider") {
 	    std::string id = next_string(jp);
-	    builder.create_h_slider(id.c_str(), next_char_pointer(jp));
+	    builder.create_feedback_slider(id.c_str(), next_char_pointer(jp));
 	} else if (jp->current_value() == "create_selector_no_caption") {
 	    builder.create_selector_no_caption(next_char_pointer(jp));
 	} else if (jp->current_value() == "create_selector") {
@@ -1477,6 +1484,10 @@ int GxMachineRemote::load_remote_ui(const UiBuilder& builder, int form) {
 	    builder.create_selector(id.c_str(), next_char_pointer(jp));
 	} else if (jp->current_value() == "create_simple_meter") {
         builder.create_simple_meter(next_char_pointer(jp));
+	} else if (jp->current_value() == "create_simple_c_meter") {
+        std::string id = next_char_pointer(jp);
+	    std::string idl = next_char_pointer(jp);
+	    builder.create_simple_c_meter(id.c_str(),idl.c_str(), next_char_pointer(jp));
 	} else if (jp->current_value() == "create_spin_value") {
 	    std::string id = next_char_pointer(jp);
 	    builder.create_spin_value(id.c_str(), next_char_pointer(jp));
@@ -1496,6 +1507,11 @@ int GxMachineRemote::load_remote_ui(const UiBuilder& builder, int form) {
 	} else if (jp->current_value() == "create_port_display") {
 	    std::string id = next_char_pointer(jp);
 	    builder.create_port_display(id.c_str(), next_char_pointer(jp));
+	} else if (jp->current_value() == "create_p_display") {
+        std::string id = next_char_pointer(jp);
+	    std::string idl = next_char_pointer(jp);
+	    std::string idh = next_char_pointer(jp);
+	    builder.create_p_display(id.c_str(),idl.c_str(),idh.c_str());
 	} else if (jp->current_value() == "create_simple_spin_value") {
 	    builder.create_simple_spin_value(next_char_pointer(jp));
 	} else if (jp->current_value() == "create_eq_rackslider_no_caption") {
