@@ -746,8 +746,10 @@ public:
     CabinetConvolver cabinet;
     PreampConvolver preamp;
     ContrastConvolver contrast;
+    LiveLooper  loop;
+    SCapture record;
 public:
-    MonoEngine(const string& plugin_dir, ParameterGroups& groups);
+    MonoEngine(const string& plugin_dir, const string& loop_dir, ParameterGroups& groups);
     ~MonoEngine();
     virtual void wait_ramp_down_finished();
     virtual bool update_module_lists();
@@ -889,7 +891,7 @@ static const char* ampstack_groups[] = {
     0
 };
 
-MonoEngine::MonoEngine(const string& plugin_dir, ParameterGroups& groups)
+MonoEngine::MonoEngine(const string& plugin_dir, const string& loop_dir, ParameterGroups& groups)
     : EngineControl(),
       resamp(),
       // ModuleSelector's
@@ -908,7 +910,9 @@ MonoEngine::MonoEngine(const string& plugin_dir, ParameterGroups& groups)
       mono_convolver(*this, sigc::mem_fun(mono_chain, &MonoModuleChain::sync), get_param()),
       cabinet(*this, sigc::mem_fun(mono_chain, &MonoModuleChain::sync), resamp),
       preamp(*this, sigc::mem_fun(mono_chain, &MonoModuleChain::sync), resamp),
-      contrast(*this, sigc::mem_fun(mono_chain, &MonoModuleChain::sync), resamp) {
+      contrast(*this, sigc::mem_fun(mono_chain, &MonoModuleChain::sync), resamp),
+      loop(get_param(), sigc::mem_fun(mono_chain, &MonoModuleChain::sync), loop_dir),
+      record(*this, 1) {
 
     mono_convolver.set_sync(true);
     cabinet.set_sync(true);
@@ -981,10 +985,13 @@ void MonoEngine::load_static_plugins() {
     pl.add(builtin_tonestack_plugins,             PLUGIN_POS_RACK, PGN_ALTERNATIVE);
 
     // mono
+    pl.add(gx_effects::gain::plugin(),   PLUGIN_POS_RACK, PGN_GUI);
     pl.add(gx_effects::low_high_pass::plugin(),   PLUGIN_POS_RACK, PGN_GUI);
     pl.add(gx_effects::highbooster::plugin(),     PLUGIN_POS_RACK, PGN_GUI);
     pl.add(gx_effects::selecteq::plugin(),        PLUGIN_POS_RACK, PGN_GUI);
     pl.add(&crybaby.plugin,                       PLUGIN_POS_RACK, PGN_GUI);
+    pl.add(&loop.plugin,                          PLUGIN_POS_RACK,  PGN_GUI);
+    pl.add(&record.plugin,                      PLUGIN_POS_RACK,  PGN_GUI);
     pl.add(gx_effects::gx_distortion::plugin(),   PLUGIN_POS_RACK, PGN_GUI);
     pl.add(pluginlib::ts9sim::plugin(),           PLUGIN_POS_RACK, PGN_GUI);
     pl.add(gx_effects::impulseresponse::plugin(), PLUGIN_POS_RACK, PGN_GUI);
@@ -1002,12 +1009,15 @@ void MonoEngine::load_static_plugins() {
     pl.add(gx_effects::gx_feedback::plugin(),     PLUGIN_POS_RACK, PGN_GUI);
     pl.add(gx_effects::peak_eq::plugin(),         PLUGIN_POS_RACK, PGN_GUI);
     pl.add(gx_effects::digital_delay::plugin(),   PLUGIN_POS_RACK, PGN_GUI);
+    pl.add(gx_effects::graphiceq::plugin(),   PLUGIN_POS_RACK, PGN_GUI);
+    pl.add(gx_effects::ring_modulator::plugin(),  PLUGIN_POS_RACK, PGN_GUI);
+	pl.add(gx_effects::duck_delay::plugin(),      PLUGIN_POS_RACK);
+	pl.add(pluginlib::reversedelay::plugin(),     PLUGIN_POS_RACK);
     pl.add(&tonestack.plugin,                     PLUGIN_POS_RACK, PGN_GUI);
     pl.add(&mono_convolver.plugin,                PLUGIN_POS_RACK, PGN_GUI);
     pl.add(&cabinet.plugin,                       PLUGIN_POS_RACK, PGN_GUI);
     pl.add(&preamp.plugin,                        PLUGIN_POS_RACK, PGN_GUI);
     pl.add(pluginlib::abgate::plugin(),           PLUGIN_POS_RACK);
-    pl.add(pluginlib::dubbe::plugin(),           PLUGIN_POS_RACK);
     pl.add(pluginlib::vibe::plugin_mono(),        PLUGIN_POS_RACK);
     pl.add(pluginlib::mbc::plugin(),              PLUGIN_POS_RACK);
     pl.add(pluginlib::mbd::plugin(),              PLUGIN_POS_RACK);
@@ -1099,7 +1109,8 @@ public:
 
 LadspaGuitarixMono::LadspaGuitarixMono(unsigned long sr)
     : LadspaGuitarix(engine, 0, &engine.mono_convolver, control_parameter, "LADSPA_GUITARIX_MONO_PRESET"),
-      engine(Glib::build_filename(Glib::get_user_config_dir(), "guitarix/plugins/"), get_group_table()),
+      engine(Glib::build_filename(Glib::get_user_config_dir(), "guitarix/plugins/"),
+       Glib::build_filename(Glib::get_user_config_dir(), "guitarix/pluginpresets/loops/"), get_group_table()),
       control_parameter(GUITARIX_PARAM_COUNT),
       rebuffer(),
       volume_port(),
@@ -1388,6 +1399,7 @@ private:
 public:
     StereoModuleChain stereo_chain;
     ConvolverStereoAdapter stereo_convolver;
+    SCapture record_st;
 public:
     StereoEngine(const string& plugin_dir, ParameterGroups& groups);
     ~StereoEngine();
@@ -1467,7 +1479,8 @@ void StereoEngine::set_samplerate(unsigned int samplerate) {
 StereoEngine::StereoEngine(const string& plugin_dir, ParameterGroups& groups)
     : EngineControl(),
       // internal audio modules
-      stereo_convolver(*this, sigc::mem_fun(stereo_chain, &StereoModuleChain::sync), get_param()) {
+      stereo_convolver(*this, sigc::mem_fun(stereo_chain, &StereoModuleChain::sync), get_param()),
+      record_st(*this, 2) {
 
     stereo_convolver.set_sync(true);
 
@@ -1513,10 +1526,16 @@ void StereoEngine::load_static_plugins() {
     pl.add(gx_effects::tonecontroll::plugin(),    PLUGIN_POS_RACK, PGN_GUI);
     pl.add(gx_effects::digital_delay_st::plugin(),PLUGIN_POS_RACK, PGN_GUI);
     pl.add(&stereo_convolver.plugin,              PLUGIN_POS_RACK, PGN_GUI);
+    pl.add(&record_st.plugin,                   PLUGIN_POS_RACK, PGN_GUI);
     pl.add(gx_effects::stereoverb::plugin(),      PLUGIN_POS_RACK, PGN_GUI);
     pl.add(pluginlib::zita_rev1::plugin(),        PLUGIN_POS_RACK);
     pl.add(pluginlib::vibe::plugin_stereo(),      PLUGIN_POS_RACK);
     pl.add(pluginlib::mbcs::plugin(),             PLUGIN_POS_RACK);
+    pl.add(gx_effects::ring_modulator_st::plugin(),PLUGIN_POS_RACK, PGN_GUI);
+	pl.add(gx_effects::duck_delay_st::plugin(),    PLUGIN_POS_RACK, PGN_GUI);
+    pl.add(gx_effects::dattorros_progenitor::plugin(),PLUGIN_POS_RACK, PGN_GUI);
+    pl.add(gx_effects::panoram_enhancer::plugin(),PLUGIN_POS_RACK, PGN_GUI);
+    pl.add(gx_effects::bass_enhancer::plugin(),   PLUGIN_POS_RACK, PGN_GUI);
 }
 
 
